﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

/// <summary>        
/// SmartI/O 입력단자 테스트
/// SmartX : SmartGPIO
/// 기능 : 스위치, 근접센서등 외부입력장치 입력기능
/// 응용분야 : 스위치, 근접센서등.. 외부입력장치
/// 항목 : 스위치, 근접센서(DC 2선식, DC 3선식<PNP>, DC 3선식<NPN>)
///      스위치 : 
///      근접센서(DC 2선식<Nomal Open>) : (주)오토닉스(PRT18-8DO)
///      근접센서(DC 3선식<PNP>) : (주)오토닉스(PR18-8DP)
///      근접센서(DC 3선식<NPN>) : (주)오토닉스(PR18-8DN)
/// 주의사항 : Com 단자가 하나라서, DC 3선식<PNP>과 DC 3선식<NPN>은 같이 Input에 사용불가.
///            채터링현상은 딜레이로 처리가능
/// </summary>

namespace TechNote53_SmartIO_INPUT_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private int[] m_iInputCount = new int[4];

        private void Form1_Load(object sender, EventArgs e)
        {
            // 현재 Form을 MainForm으로 설정합니다.
            smartForm1.MainForm = this;
            // SmartGPIO의 Port를 B로 설정
            smartGPIO1.PortSelect = SmartX.SmartGPIO.PORTID.PORTB;
            // PortB의 상태를 ALL Low로 설정
            smartGPIO1.PortDatas = 0;
            // PortB의 방향을 ALL Input으로 설정
            smartGPIO1.PortDirs = 0;
            // PortB의 상태 변경을 체크하는 이벤트 시작
            smartGPIO1.PortWatchStart();

            smartPictureBox1.AddImageList(Resource1.Switch_1);
            smartPictureBox1.AddImageList(Resource1.Switch_0);
            smartPictureBox1.DrawNext(0);

            smartPictureBox2.AddImageList(Resource1.Sensor1_1);
            smartPictureBox2.AddImageList(Resource1.Sensor1_0);
            smartPictureBox2.DrawNext(0);

            smartPictureBox3.AddImageList(Resource1.Sensor2_1);
            smartPictureBox3.AddImageList(Resource1.Sensor2_0);
            smartPictureBox3.DrawNext(0);

            smartPictureBox4.AddImageList(Resource1.Sensor1_1);
            smartPictureBox4.AddImageList(Resource1.Sensor1_0);
            smartPictureBox4.DrawNext(0);
        }

        // PortB의 상태 변경이 감지되었을 때 발생되는 이벤트
        private void smartGPIO1_OnPortDatasChange(int iPortDatas)
        {
            SmartX.SmartGPIO.PORTPIN iBit;

            iBit = smartGPIO1.PortDetection(SmartX.SmartGPIO.PORTID.PORTB, SmartX.SmartGPIO.TRIGGERMODE.LowActive, iPortDatas);

            switch (iBit)
            {
                case SmartX.SmartGPIO.PORTPIN.PIN0:
                    labCount0.Text = (++m_iInputCount[0]).ToString();
                    smartPictureBox1.DrawNext(1);
                    break;
                case SmartX.SmartGPIO.PORTPIN.PIN1:
                    labCount1.Text = (++m_iInputCount[1]).ToString();
                    smartPictureBox2.DrawNext(1);
                    break;
                case SmartX.SmartGPIO.PORTPIN.PIN2:
                    labCount2.Text = (++m_iInputCount[2]).ToString();
                    smartPictureBox3.DrawNext(1);
                    break;
                case SmartX.SmartGPIO.PORTPIN.PIN3:
                    labCount3.Text = (++m_iInputCount[3]).ToString();
                    smartPictureBox4.DrawNext(1);
                    break;
                case SmartX.SmartGPIO.PORTPIN.ZERO:
                    smartPictureBox1.DrawNext(0);
                    smartPictureBox2.DrawNext(0);
                    smartPictureBox3.DrawNext(0);
                    smartPictureBox4.DrawNext(0);
                    break;
            }
        }

        // PORTB Display 초기화
        private void btnInitial_Click(object sender, EventArgs e)
        {
            // Count 초기화
            for (int i = 0; i < 4; i++)
            {
                m_iInputCount[i] = 0;
            }

            // Count 표시 초기화
            labCount0.Text = "0";
            labCount1.Text = "0";
            labCount2.Text = "0";
            labCount3.Text = "0";
        }
    }
}
